| Title: | Retrieve Data From the 'BAAD' (Biomass And Allometry Database) |
|---|---|
| Description: | Retrieves data from the Biomass And Allometry Database ('baad'). This simplifies the task of keeping a consistently referenceable set of data on a computer without having to manually cache it. |
| Authors: | Daniel Falster, Rich FitzJohn |
| Maintainer: | Daniel Falster <[email protected]> |
| License: | BSD_2_clause + file LICENSE |
| Version: | 1.0.1 |
| Built: | 2026-05-16 06:20:34 UTC |
| Source: | https://github.com/traitecoevo/baad.data |
Load data from the Biomass and Allometry Database.
baad_data(version = NULL, path = NULL) baad_data_del(version, path)baad_data(version = NULL, path = NULL) baad_data_del(version, path)
version |
Version to load. Verion "1.0.0" corresponds to the version published in Ecology in 2015. Other valid versions are "0.1.0", "0.2.0" and "0.9.0" which are stored on github but are of historical interest only. |
path |
Optional path in which to store the data. If omitted
we use |
The first time this is run for a given version, this function will download the Biomass and Allometry Database (BAAD) from github, using numbered versions), unpack the resulting zip file and load the csv files. This might take a few seconds to a minute. Subsequent calls will be considerably quicker because we cache both the downloaded data and the result of reading the csv. Subsequent calls after that will be essentially instantaneous.
The function baad_delete deletes all traces of downloaded
BAAD data if a version is not given, or a specific version if that
is listed.
## Not run: baad <- baad_data() head(baad$data) ## End(Not run)## Not run: baad <- baad_data() head(baad$data) ## End(Not run)
Information to describe how to process github releases
baad_data_info(path = NULL)baad_data_info(path = NULL)
path |
Optional path in which to store the data. If omitted
we use |
Get release versions
baad_data_versions(local = TRUE, path = NULL) baad_data_version_current(local = TRUE, path = NULL)baad_data_versions(local = TRUE, path = NULL) baad_data_version_current(local = TRUE, path = NULL)
local |
Should we return local (TRUE) or github (FALSE)
version numbers? Github version numbers are pulled once per
session only. The exception is for
|
path |
Optional path in which to store the data. If omitted
we use |